Localization.define('fr_FR') do |l|
  # General
  l.store "your blog", "votre blog"
  l.store "Typo admin", "administration typo"
  l.store "Publish", "Écrire"
  l.store "Manage", "Gérer"
  l.store "Feedback", "Commentaires"
  l.store "Themes", "Thèmes"
  l.store "Plugins", "Greffons"
  l.store "Users", "Utilisateurs"
  l.store "Settings", "Configuration"
  l.store "Things you can do", "Vous pouvez"
  l.store "with %s AER OS XK iconset iconset %s", "avec %s les icônes AER OS XK iconset %s"
    
  #accounts/login.rhtml
  l.store "Administration", "Administration"
  l.store "Username", "Identifiant"
  l.store "Password", "Mot de passe"
  l.store "Login", "Connexion"
  l.store "Back to ", "Revenir à "
  l.store "Login unsuccessful", "Échec de la connexion"
  l.store "Login successful", "Connexion réussie"

  # admin/logout.rhtml
  l.store "Successfully logged out", "Vous êtes maintenant déconnecté"
  
  # admin/signup.rhtml
  l.store "Signup", "S'inscrire"
  l.store "Desired login", "Identifiant souhaité"
  l.store "Display name", "Nom affiché sur le site"
  l.store "Email", "Courriel"
  l.store "Choose password", "Mot de passe"
  l.store "Confirm password", "Confirmez le mot de passe"
  l.store "Signup successful", "Inscription réussie"
  
  # admin/dashboard/index.rhtml
  l.store "What can you do ?", "Vous pouvez"
  l.store "Write a post", "Écrire un billet"
  l.store "Write a page", "Écrire une page"
  l.store "Update your profile or change your password", "Mettre votre profil à jour ou changer votre mot de passe"
  l.store "Change your blog presentation", "Changer l'apparence de votre blog"
  l.store "Enable plugins", "Ajouter des greffons"
  l.store "Last Comments", "Derniers commentaires"
  l.store "Last posts", "Derniers billets"
  l.store "Most popular", "Billets les plus populaires"
  l.store "Typo documentation", "Accéder à la documentation officielle de Typo"
  l.store "No comments yet", "Aucun commentaire"
  l.store "Nothing to show yet", "Rien à déclarer"
  l.store "No posts yet, why don't you start and write one", "Vous n'avez encore écrit aucun billet, pourquoi ne pas commencer par là"
  l.store "You have no internet connection", "Vous n'avez pas de connection à internet"
  
  #admin/base/recent_comments.rhtml
  l.store "Recent comments", "Derniers commentaires"

  #admin/base/recent_trackbacks.rhtml
  l.store "Recent trackbacks", "Derniers rétroliens"
  
  #admin/blacklist/_blacklis_patterns.rhtml
  l.store "Pattern", "Motif"
  l.store "Type", "Type"
  l.store "Edit", "Éditer"
  l.store "Delete", "Supprimer"
  
  #admin/blacklist/_form.rhtml
  l.store "String", "Chaîne de caractères"
  l.store "Regex", "Expression rationnelle"
  
  #admin/blacklist/_quick_post.rhtml
  l.store "Add pattern", "Ajouter le motif"
  l.store "Cancel", "Annuler"
  l.store "or", "ou"
  
  #admin/blacklist/destroy.rhtml
  l.store "Blacklist Patterns", "Liste noire"
  l.store "Show this pattern", "Voir ce motif"
  l.store "Are you sure you want to delete this item?", "Êtes vous certain de vouloir supprimer cette entrée ?"
  
  #admin/blacklist/edit.rhtml
  l.store "Editing pattern", "Éditer un motif"
  
  #admin/blacklist/list.rhtml
  l.store "Create new Blacklist", "Ajouter une liste noire"
  
  #admin/cache/list.rhtml
  l.store "Cache", "Cache"
  
  #admin/categories/_categories.rhtml
  l.store "Category title", "Nom de la catégorie"
  l.store "%d Articles", ["Un Billet", "%d Billets"]
  
  #admin/categories/_form.rhtml
  l.store "Name", "Titre"
  
  #admin/categories/_quick_post.rhtml
  l.store "Title", "Titre"
  l.store "Add category", "Ajouter la catégorie"
  
  #admin/categorie/destroy.rhtml
  l.store "%d categories",  ["Une catégorie", "%d Catégories"]
  l.store "Show this category", "Voir cette catégorie"
  l.store "Delete this category", "Supprimer cette catégorie"
  l.store "Are you sure you want to delete the category ", "Êtes vous certain de vouloir supprimer la catégorie "

  #admin/category/list.html.erb
  l.store "add new", "ajouter nouveau"
  
  #admin/category/edit.rhtml
  l.store "Editing category", "Modifier une catégorie" 
  
  #admin/category/list.rhtml
  l.store "Manage Categories", "Gérer les catégories"
  l.store "Create new category", "Ajouter une catégorie"
  l.store "Reorder", "Trier"
  l.store "Sort alphabetically", "Trier par ordre alphabétique"
  l.store "Manage Articles", "Gérer les billets"
  l.store "Manage Pages", "Gérer les pages"
  l.store "Manage Resources", "Gérer les ressources"
  
  #admin/category/reorder.rhtml
  l.store "(Done)", "(Terminé)"
  
  #admin/category/show
  l.store "Edit this category", "Modifier cette catégorie"
  l.store "Articles in", "Billets contenus dans"

  #admin/comments/_form.rhtml
  l.store "Author", "Auteur"
  l.store "Url", "Site"
  l.store "Body", "Contenu du message" 
  
  #admin/comments/comments.rhtml
  l.store "on", "sur"

  #admin/comments/destroy.rhtml
  l.store "Comments for", "Commentaires pour"
  
  #admin/comments/edit.rhtml
  l.store "Show this comment", "Afficher ce commentaire"
  l.store "View comment on your blog", "Voir ce commentaire sur votre blog"
  l.store "Editing comment", "Modifier un commentaire"
  
  #admin/comments/list.rhtml
  l.store "IP", "Adresse IP"
  l.store "Posted date", "Envoyé le"
  
  #admin/comments/new.rhtml
  l.store "Creating comment", "Ajouter un commentaire"
  
  #admin/content/list.rhtml
  l.store "Manage posts", "Administrer les billets"
  l.store "Manage uploads", "Administrer les pièces jointes"
  l.store "Manage categories", "Administrer les catégories"
  l.store "Manage pages", "Administrer les pages"
  l.store "Post title", "Titre du billet"
  l.store "Posted at", "Date de publication"
  l.store "Posted on", "Publié le"
  l.store "%d Comments", ["Un commentaire", "%d Commentaires"]
  l.store "%d Trackbacks", ["Un rétrolien", "%d Rétroliens"]
  l.store "View", "Voir"
  l.store "Status", "État"
  l.store "Offline", "Hors ligne"
  l.store "Online", "En ligne"
  l.store "no trackbacks", "aucun rétrolien"
  l.store "no comments", "aucun commentaire"
  l.store "Posts", "Billets"
  l.store "Comments", "Commentaires"
  l.store "Categories", "Catégories"
  
  #admin/content/_attachment.rhtml
  l.store "Remove", "Supprimer"
  l.store "Really delete attachment", "Voulez-vous vraiment supprimer la pièce jointe"
  l.store "Add Another Attachment", "Ajouter une autre pièce jointe"
  
  #admin/content/_form.rhtml
  l.store "Article Body", "Corps du billet"
  l.store "Post", "Contenu"
  l.store "Optional extended content", "Contenu étendu (optionnel)"
  l.store "Article Content", "Contenu du billet"
  l.store "Extended Content", "Contenu étendu"
  l.store "Tags", "Mots clés"
  l.store "Save", "Sauver"
  l.store "Article Attachments", "Pièces Jointes"
  l.store "Article Options", "Options du billet"
  l.store "Permalink", "Lien permanent"
  l.store "Allow comments", "Autoriser les commentaires"
  l.store "Allow trackbacks", "Autoriser les rétroliens"
  l.store "Online", "En ligne"
  l.store "Publish at", "Publié le"
  l.store "Textfilter", "Formatage du texte"
  l.store "Toggle Extended Content", "Afficher le contenu étendu"
  l.store "These are advanced options. Only experimented users should use them", "Options avancées. À ne modifier que par des utilisateurs expérimentés"
  
  #admin/content/_pages.rhtml
  l.store "Previous page", "Page précédente"
  l.store "Next page", "Page suivante"
  
  #admin/content/_show_categories.rhtml
  l.store "Currently this article is listed in following categories", "Cet article est actuellement lié aux catégories suivantes"
  l.store "You can add it to the following categories", "Vous pouvez le lier aux catégories suivantes"
  
  #admin/content/_show_ressources.rhtml
  l.store "Currently this article has the following resources", "Les fichiers suivants sont actuellement liés à ce billet"
  l.store "You can associate the following resources", "Vous pouvez y lier les fichiers suivants"
  
  #admin/content/destroy.rhtml
  l.store "Show this article", "Voir ce billet"
  l.store "Are you sure you want to delete this article", "Êtes-vous certain de vouloir supprimer ce billet"
  l.store "Delete this article", "Supprimer ce billet"
  
  #admin/content/edit.rhtml
  l.store "Edit Article", "Éditer un billet"
  l.store "View article on your blog", "Voir ce billet sur votre blog"

  #admin/content/preview.rhtml
  l.store "Posted by", "Publié par"
  
  #admin/content/show.rhtml
  l.store "Preview Article", "Prévisualiser un billet"
  l.store "Edit this article", "Modifier ce billet"
  l.store "Last updated", "Dernière modification"
  l.store "Attachments", "Pièces jointes"
  
  #admin/feedback/list.rhtml
  l.store "Limit to spam", "Afficher le spam"
  l.store "Limit to unconfirmed", "Afficher les commentaires en attente"
  l.store "Limit to unconfirmed spam", "Afficher les commentaires douteux"
  l.store "Blacklist", "Liste noire"
  l.store "Feedback Search", "Rechercher dans les discussions"
  l.store "Comments and Trackbacks for", "Commentaires et rétroliens pour"

  #admin/feedback/index.html.erb
  l.store "Limit to ham", "Uniquement les commentaires valides"
  
  #admin/feedback/article.html.erb
  l.store "All comments", "Tous les commentaires"

  #admin/feedback/create
  l.store "Comment was successfully created.", "Commentaire crée avec succès."
  l.store "Comment was successfully updated.", "Commentaire mis à jour avec succès."
 
  #admin/general/task
  l.store "Basic settings", "Configuration de base"
  l.store "Advanced settings", "Configuration avancée"
  l.store "Blog advanced settings", "Configuration avancée du blog"
  
  #admin/general/index.rhtml
  l.store "Blog settings", "Configuration du blog"
  l.store "Which settings group would you like to edit", "Quel groupe d'options souhaitez-vous modifier "
  l.store "General settings", "Options générales"
  l.store "General Settings", "Options générales"
  l.store "Read", "Lire"
  l.store "Write", "Écrire"
  l.store "Discuss", "Discuter"
  l.store "Notification", "Notifications"
  l.store "Spam Protection", "Protection contre le spam"
  l.store "Resource Settings", "Options des pièces jointes"
  l.store "Cache", "Cache"
  l.store "Blog name", "Titre du blog"
  l.store "Blog subtitle", "Sous-titre du blog"
  l.store "Language", "Langue"
  l.store "Blog URL", "Adresse du blog"
  l.store "Latitude, Longitude", "Latitude, Longitude"
  l.store "Display", "Afficher"
  l.store "your lattitude and longitude", "votre lattitude et votre longitude"
  l.store "exemple", "par exemple"
  l.store "Search Engine Optimisation", "Optimisation pour les moteurs de recherche"
  l.store "Show blog name", "Afficher le titre du blog"
  l.store "At the beginning of page title", "Au début du titre de la page"
  l.store "At the end of page title", "À la fin du titre de la page"
  l.store "Don't show blog name in page title", "Ne pas afficher le nom du blog dans le titre de la page"
  l.store "Save Settings", "Enregistrer les options"
  l.store "articles on my homepage by default", "billet sur ma page d'accueil"
  l.store "articles in my news feed by default", "billets dans mon flux RSS"
  l.store "Show full article on feed", "Afficher la totalité du billet dans le flux RSS"
  l.store "Article filter", "Mise en forme des billets"
  l.store "Comments filter", "Mise en forme des commentaires"
  l.store "When publishing articles, Typo can send trackbacks to websites that you link to. This should be disabled for private blogs as it will leak non-public information to sites that you're discussing. For public blogs, there's no real point in disabling this.", "Quand vous publiez un billet sur Typo, vous pouvez envoyer un rétrolien aux sites que vous liez. Cette fonctionnalité devrait être désactivée pour les blogs privée puisqu'elle permet de donner des informations à leur sujet à des tiers. Ceci ne s'impose cependant pas pour un blog public."
  l.store "Send trackbacks", "Envoyer des rétroliens"
  l.store "URLs to ping automatically", "Sites à alerter automatiquement"
  l.store "This setting allows you to disable trackbacks for every article in your blog.  It won't remove existing trackbacks, but it will prevent any further attempt to add a trackback anywhere on your blog.", "Cette option vous permet de désactiver totalement les rétroliens sur votre blog. Ceci ne supprimera pas les rétroliens existants, mais empêchera tout nouveau rétrolien d'être créé"
  l.store "Disable trackbacks site-wide" ,"Désactiver globalement les rétroliens"
  l.store "Enable Trackbacks by default", "Activer les rétroliens par défaut"
  l.store "You can enable site wide feeback moderation. If you do so, no comment or trackback will appear on your blog unless you validate it", "Vous pouvez activez la modération des commentaires sur l'ensemble de votre site. Si vous le faites, aucun commentaire ou rétrolien ne sera publié sans une validation de votre part"
  l.store "Enable feedback moderation", "Activer la modération des commentaires"
  l.store "Enable comments by default", "Activer les commentaires par défaut"
  l.store "Show your email address", "Afficher votre adresse courriel"
  l.store "Enable gravatars", "Activer les gratavars"
  l.store "You can optionally disable non-Ajax comments. Typo will always use Ajax for comment submission if Javascript is enabled, so non-Ajax comments are either from spammers or users without Javascript.", "Vous pouvez désactiver l'envoi des commentaires en AJAX. Typo utilisera toujours l'AJAX par défaut pour envoyer les commentaires si Javascript est activé. Désactiver l'AJAX sert donc aux gens ne disposant pas de Javascript et aux robots spammeurs"
  l.store "Allow non-ajax comments", "Autoriser l'envoi de commentaires sans AJAX"
  l.store "Disable comments after", "Désactiver les commentaires au bout de "
  l.store "Set to 0 to never disable comments", "Mettez cette option à 0 pour ne jamais désactiver les commentaires dans le temps"
  l.store "Typo will automatically reject comments and trackbacks which contain over a certain amount of links in them", "Typo rejettera automatiquement les commentaires et les rétroliens contenant un certain nombre de liens"
  l.store "Max Links", "Nombre de liens maximum"
  l.store "Set to 0 to never reject comments", "Mettez cette option à 0 pour ne jamais rejeter les commentaires"
  l.store "Typo can notify you when new articles or comments are posted", "Typo peut vous alerter quand de nouveaux articles et commentaires sont publiés"
  l.store "Source Email", "Adresse courriel source"
  l.store "Email address used by Typo to send notifications", "Adresse courriel utilisée par Typo pour l'envoi d'alertes"
  l.store "Jabber account", "Compte Jabber"
  l.store "Spam protection", "Protection contre le spam"
  l.store "Enabling spam protection will make typo compare the IP address of posters as well as the contents of their posts against local and remote blacklists. Good defense against spam bots", "La protection contre le spam permettra à typo de comparer l'adresse IP des commentateurs ainsi que le contenu de leurs commentaires avec une liste noire distante"
  l.store "Enable spam protection", "Activer la protection contre le spam"
  l.store "Typo can (optionally) use the %s spam-filtering service.  You need to register with Akismet and receive an API key before you can use their service.  If you have an Akismet key, enter it here", "Typo peut utiliser le service de lutte contre le spam %s. Vous devez vous enregistrer afin de pouvoir utiliser les services d'Akismet. Si vous possédez une clé Akismet, ajoutez là ici"
  l.store "Akismet Key", "Clé Akismet"
  l.store "The below settings act as defaults when you choose to publish an enclosure with iTunes metadata", "Les options suivantes seront ajoutées automatiquement quand vous publierez des enclosures contenant des métadonnées iTunes"
  l.store "Subtitle", "Sous-titre"
  l.store "Summary", "Résumé"
  l.store "Setting for channel", "Options des canaux"
  l.store "Optional Name", "Nom facultatif"
  l.store "Not published by Apple", "Donnée non publiée par Apple"
  l.store "Copyright Information", "Informations sur le copyright"
  l.store "Explicit", "Contenu explicite"
  l.store "Empty Fragment Cache", "Vider le cache"
  l.store "Rebuild cached HTML", "Reconstruire le HTML en cache"
  l.store "days", "jours"
  l.store "General options", "Options générales"
  l.store "By default, Typo generates static HTML pages for your posts. However, if you plan to publish posts in the futur, you may want to use semi dynamic caching", "Par défaut, Typo génère des pages HTML statiques. Cependant, si vous prévoyez d'utiliser les fonctionnalités de publication dans le futur, il vous faudra utiliser le cache dynamique"
  l.store "Use static HTML page caching", "Utiliser le cache statique"
  l.store "Use semi static caching (default)", "Utiliser le cache dynamique (option par défaut)"
  l.store "Choose caching methode", "Sélectionnez la méthode de cache"
  
  #admin/general/update_database
  l.store "Database migration", "Mise à jour de la base de données"
  l.store "Information", "Informations"
  l.store "Current database version", "Version actuelle de la base"
  l.store "New database version", "Nouvelle version de la base"
  l.store "Your database supports migrations", "Votre base de données supporte la mise à jour"
  l.store "yes", "oui"
  l.store "no", "non"
  l.store "Needed migrations", "Mise à jour nécessaire"
  l.store "You are up to date!", "Vous êtes à jour !"
  l.store "Update database now", "Mettez votre base à jour"
  l.store "may take a moment", "cela peut prendre un moment"
  l.store "config updated.", "Configuration mis à jour."
  
  #admin/pages/_form.rhtml
  l.store "Page Body", "Contenu de la page"
  l.store "Page Content", "Contenu de la page"
  l.store "Location", "Lien permanent"
  l.store "Page Options", "Options de la page"
  
  #admin/pages/_pages.rhtml
  l.store "Action", "Actions"
  l.store "Pages","Gérer les pages"
  l.store "Show this page", "Afficher cette page"
  l.store "Are you sure you want to delete the page", "Voulez-vous vraiment effacer cette page"
  l.store "Delete this page", "Supprimer cette page"
  
  #admin/pages/edit.rhtml
  l.store "Create new page", "Ajouter une page"
  l.store "View page on your blog", "Afficher cette page sur votre blog"
  l.store "Editing page", "Modifier une page"
  l.store "Manage Text Filters", "Gérer l'affichage des billets"
  
  #admin/pages/show.rhtml
  l.store "Edit this page", "Modifier cette page"
  l.store "by", "par"
  
  #admin/ressources/_metadata_add.rhtml
  l.store "Resource MetaData", "Méta données des pièces jointes"
  l.store "Set iTunes metadata for this enclosure", "Ajouter des méta données iTunes pour cette pièce jointe"
  l.store "Duration", "Durée"
  l.store "Key Words", "Mots clé"
  l.store "seperate with spaces", "séparez-les par des espaces"
  l.store "Category", "Catégorie"

  #admin/resources/_metadata_edit.rhtml
  l.store "Remove iTunes Metadata", "Supprimer les méta données iTunes"
  l.store "Content Type", "Type de contenu"
  
  #admin/resources/_resources.rhtml
  l.store "Filename", "Fichier"
  l.store "right-click for link", "clic droit pour le lien"
  l.store "MetaData", "Méta données"
  l.store "File Size", "Taille du fichier"
  l.store "Uploaded", "Ajouté le"
  l.store "Edit MetaData", "Modifier les méta données"
  l.store "Add MetaData", "Ajouter des méta données"

  #admin/resources/destroy.rhtml
  l.store "File Uploads", "Ajout de fichiers"
  l.store "Upload a new File", "Ajouter un fichier"
  l.store "Are you sure you want to delete this file", "Êtes-vous certain de vouloir supprimer ce fichier"
  l.store "Delete this file from the webserver?", "Supprimer complètement ce fichier du site ?"

  #admin/resources/new.rhtml
  l.store "Upload a File to your Site", "Envoyer un fichier sur votre site"
  l.store "Upload", "Ajouter un fichier joint"
  l.store "Upload a new Resource", "Ajouter une pièce jointe"
  l.store "File", "Fichier"
  
  #admin/sidebar/_avaliables.rhtml
  l.store "You have no plugins installed", "Aucun greffon n'est disponible"
  
  #admin/sidebar/_publish.rhtml
  l.store "Changes published", "Modifications effectuées"
  
  #admin/sidebar/_target.rhtml
  l.store "Drag some plugins here to fill your sidebar", "Déplacez des greffons dans cet espace afin de remplir votre sidebar"
  
  #admin/sidebar/index.rhtml
  l.store "Choose a theme", "Sélectionnez un thème"
  l.store "Drag and drop to change the sidebar items displayed on this blog.  To remove items from the sidebar just click remove  Changes are saved immediately, but not activated until you click the 'Publish' button", "Glissez / déplacez des éléments pour changer la sidebar de votre blog. Pour supprimer un élément de votre sidebar, cliquez simplement sur 'supprimer'. Les changements sont effectués immédiatement, mais ne seront pas actifs tant que vous n'aurez pas cliqué sur le bouton 'Publier'."
  l.store "Publish changes", "Publier les modifications"
  l.store "Available Items", "Éléments disponibles"
  l.store "Active Sidebar items", "Éléments utilisés"

  #admin/textfilters/_form.rhtml
  l.store "Description", "Déscription"
  l.store "Markup type", "Type de balises"
  l.store "Post-processing filters", "Filtres de post production"
  l.store "Parameters", "Paramètres"
  
  #admin/textfilters/_macros.rhtml
  l.store "Show Help", "Afficher l'aide"
  
  #admin/textfilters/_textfilters.rhtml
  l.store "Markup", "Balisage"
  l.store "Filters", "Filtres"
  
  #admin/textfilters/destroy.rhtml
  l.store "Text Filters", "Mise en forme du texte"
  l.store "Are you sure you want to delete this filter", "Êtes-vous certain de vouloir supprimer ce filtre"
  l.store "Delete this filter", "Supprimer ce filtre"
  
  #admin/textfilters/edit.rhtml
  l.store "Editing textfilter", "Modifier un filtre"
  
  #admin/textfilters/list.rhtml
  l.store "Create new text filter", "Ajouter une mise en forme de texte"
  l.store "Customize Sidebar", "Personnaliser la sidebar"
  l.store "Macros", "Macros"
  
  #admin/textfilters/macro_help.rhtml
  l.store "Macro Filter Help", "Aide des macros de filtrage"
  l.store "Creating text filter", "Ajouter une nouvelle mise en forme de texte"
  
  #admin/textfilters/show.rhtml
  l.store "Text Filter Details", "Détails de la mise en forme"
  l.store "Edit this filter", "Modifier cette mise en forme"
  l.store "See help text for this filter", "Afficher l'aide de ce filtre"
  
  #admin/themes/index.rhtml
  l.store "Choose theme", "Choisissez un thème"
  l.store "Theme editor", "Éditeur de thèmes"
  l.store "Activate", "Activer"
  l.store "Active theme", "Thème actif"
  l.store "You can download third party themes from officially supported %s ", "Vous pouvez télécharger des thèmes officiellement supportés sur %s "
  l.store "dev 411 Typo themes viewer", "le visualisateur de thèmes de dev411"

  #admin/themes/catalogue.html.erb
  l.store "Theme catalogue", "Catalogue de thème"
  l.store "Sorry the theme catalogue is not available", "Désolé le catalogue de thème n'est pas disponible"
  
  #admin/trackbacks/edit.rhtml
  l.store "Trackbacks for", "Rétroliens pour"
  l.store "Editing trackback", "Modifier un rétrolien"
  
  #admin/trackbacks/new.rhtml
  l.store "Creating trackback", "Ajouter un rétrolien"
  l.store "Edit this trackback", "Modifier ce rétrolien"
  
  #admin/users/_form.rhtml
  l.store "Jabber", "Jabber"
  l.store "Password Confirmation", "Confirmer le mot de passe"
  l.store "Send notification messages via email", "Envoyer des alertes par courriel"
  l.store "Send notification messages when new articles are posted", "Envoyer des alertes à la publication de nouveaux billets"
  l.store "Send notification messages when comments are posted", "Envoyer des alertes à la publication de nouveaux commentaires"
  l.store "Login", "Login"
  l.store "Profile", "Profil"
  l.store "Display Name", "Nom affiché"
  l.store "Email", "Email"
  l.store "Password", "Mot de passe"
  l.store "Password confirmation", "Confirmation du mot de passe"
  l.store "Send notification messages via email", "Envoi de notification des messages par email"
  l.store "Send notification messages when new articles are posted", "Envoi de notification de messages quand de nouveaux articles sont postés" 
  l.store "Send notification messages when comments are posted", "Envoi de notification de messages quand des commentaires sont postés"

  #admin/user/new.html.erb
  l.store "Add User", "Ajout d'utilisateur"
  l.store "Users", "Utilisateurs"
  
  #admin/user/_user.rhtml
  l.store "Number of Articles", "Nombre de billets"
  l.store "Number of Comments", "Nombre de commentaires"
  l.store "Notified", "Alerté"
  l.store "via email", "par email"
  
  #admin/user/destroy.rhtml
  l.store "Show this user", "Voir cet utilisateur"
  l.store "Really delete user", "Vraiment supprimer cet utilisateur"
  
  #admin/user/edit.rhtml
  l.store "Edit User", "Modifier un utilisateur"
  l.store "Editing User", "Modification d'un utilisateur"
  l.store "New User", "Ajouter un utilisateur"
  l.store "Add new user", "Ajouter un utilisateur"
  
  #admin/user/new.rhtml
  l.store "Creating user", "Ajouter un nouvel utilisateur"
  
  #admin/user/show.rhtml
  l.store "User's articles", "Articles publiés par cet utilisateur"
  l.store "Notify via email", "Cet utilisateur reçoit des alertes par courriel"
  l.store "Notify on new articles", "Cet utilisateur est alerté à la publication d'un nouveau billet"
  l.store "Notify on new comments", "Cet utilisateur est alerté à la publication d'un nouveau commentaire"
  
  #articles/_comment.rhtml
  l.store "said", "a dit"
  l.store "This comment has been flagged for moderator approval.  It won't appear on this blog until the author approves it", "Ce commentaire a été envoyé à la modération. Il ne sera affiché qu'une fois approuvé par un modérateur"
  
  #articles/_comment_box.rhtml
  l.store "Your name", "Votre nom "
  l.store "Your blog", "Votre blog "
  l.store "Your email", "Votre courriel"
  l.store "Your message", "Votre commentaire"
  l.store "Comment Markup Help", "Aide sur le balisage des commentaires"
  l.store "Preview comment", "Prévisualiser le commentaire"
  
  #articles/_trackback.rhtml
  l.store "From", "De"
  
  #articles/archives.rhtml
  l.store "No articles found", "Aucun article ne correspond à la recherche"
  
  #articles/comment_preview.rhtml
  l.store "is about to say", "va dire"
  
  #articles/groupings.rhtml
  l.store "There are", "Il y a"
  
  #articles/index.rhtml
  l.store "Read more", "Lire la suite"
  l.store "Older posts", "Articles précédents"
  
  #articles/read.rhtml
  l.store "Leave a response", "Commenter"
  l.store "Use the following link to trackback from your own site", "Utilisez le lien suivant afin d'envoyer un rétrolien depuis votre site"
  l.store "RSS feed for this post", "Flux RSS de ce billet"
  l.store "trackback uri", "URL de rétrolien"
  l.store "Comments are disabled", "Les commentaires sont désactivés"
 
  l.store "Pictures from", "Images de"
  
  #vendor/plugins/aimpresence_sidebar/aimpresence_sidebar.rb
  l.store "AIM Presence", "Statut AIM"

  #vendor/plugins/aimpresence_sidebar/views/content.rb
  l.store "AIM Status", "Statut AIM"
  
  #vendor/plugins/xml_sidebar/xml_sidebar.rb
  l.store "XML Syndication", "Syndication XML"

  #vendor/plugins/xml_sidebar/xml_sidebar.rb
  l.store "Syndicate", "Suivre ce blog"
  
  #vendor/plugins/archives_sidebar/views/content.rb
  l.store "Archives", "Archives"
    
  #app/helpers/admin/base_helper.rb
  l.store "Back to overview", "Revenir à la liste"
  l.store "log out", "déconnexion"

  #app/controller/admin/cache_controller.rb
  l.store "Cache was cleared", "Le cache est vidé"
  l.store "HTML was cleared", "l'HTML est vidé"

  #app/controller/admin/categories_controller.rb
  l.store "Category was successfully created.", "Catégorie ajoutée avec succès"
  l.store "Category could not be created.", "La catégorie n'a pu être créée"
  l.store "Category was successfully updated.", "Catégorie mis à jour avec succès"

  #app/models/article.rb
  l.store "New post", "Nouveau billet"
  l.store "A new message was posted to ", "Une nouveau message a été posté sur "

  #app/helper/application_helper.rb
  l.store "no ", "aucun "

  #app/controller/admin/resource_controller.rb
  l.store "File uploaded: ", "Fichier uploader: "
  l.store "Unable to upload", "impossible d'uploader"
  l.store "Metadata was successfully removed.", "Les Metadata ont été supprimé avec succès."
  l.store "Metadata was successfully updated.", "Les Metadata ont été mis à jour avec succès."
  l.store "Not all metadata was defined correctly.", "Aucun metada n'a été défini correctement."
  l.store "Content Type was successfully updated.", "Le type du contenu a été mis à jour avec succès."
  l.store "Error occurred while updating Content Type.", "Une erreur est survenue lors de la mise à jour du type du contenu."
  l.store "complete", "complet"

  #app/controller/admin/user_controller.rb
  l.store "User was successfully updated.", "L'utilisateur a été mis à jour avec succès."
  l.store "User was successfully created.", "L'utilisateur a été créé avec succès."


  
  # Themes
  l.store "Home", "Accueil"
  l.store "About", "À propos"
  l.store "Designed by %s ported to typo by %s ", "Design par %s porté sous Typo par %s"
  l.store "Powered by %s", "Propulsé par %s"
  l.store "Read full article", "Lien permanent"
  l.store "Search", "Chercher"
  l.store "Continue reading...", "Lire la suite..."
  l.store "Posted by", "Publié par"
  l.store "January", "Janvier"
  l.store "February", "Février"
  l.store "March", "Mars"
  l.store "April", "Avril"
  l.store "May", "Mai"
  l.store "June", "Juin"
  l.store "July", "Juillet"
  l.store "August", "Août"
  l.store "September", "Septembre"
  l.store "October", "Octobre"
  l.store "November", "Novembre"
  l.store "December", "Décembre"
  l.store "This entry was posted on %s", "Ce billet a été posté le %s"
  l.store "Posted in", "Publié sous"
  l.store "and %s", "et %s"
  l.store "Atom feed", "flux Atom"
  l.store "You can follow any any response to this entry through the %s", "Vous pouvez suivre la discussion autour de cet article via le %s"
  l.store "You can leave a %s", "Vous pouvez déposer un %s"
  l.store "or a %s from your own site", "ou un %s depuis votre site"
  l.store "later", "plus tard"
  l.store "Leave a comment", "laisser un commentaire"
  l.store "Name %s", "Votre nom %s"
  l.store "required", "obligatoire"
  l.store "Preview", "Prévisualiser "
  l.store "enabled", "activés"
  l.store "never displayed", "jamais affiché"
  l.store "Comments", "Commentaires"
  l.store "Website", "Votre site"
  l.store "Textile enabled", "Textile activé"
  l.store "Markdown enabled", "Markdown activé"
  l.store "Submit", "Envoyer"
  l.store "is about to say", "va dire"
  l.store "Older posts", "Billets précédents"
  l.store "Use the following link to trackback from your own site", "Utilisez le lien ci-dessous pour envoyer un trackback depuis votre site"
  l.store "Leave a response", "Réagir à ce billet"
  l.store "styled width %s", "design %s"
  l.store "Searching", "Recherche en cours"
  l.store "permalink", "lien permanent"
  l.store "Name", "Nom"
  l.store "leave url/email", "laissez votre url/courriel"
  l.store "No comments", "Pas de commentaires"
  l.store "From", "De"
  l.store "Meta", "Méta"
  l.store "comment", "commentaire"
  l.store "comments", "commentaires"
  l.store "posted in", "publié dans"
  
  # Dates 
  l.store "Mon", "Lun"
  l.store "Tue", "Mar"
  l.store "Wed", "Mer"
  l.store "Thu", "Jeu"  
  l.store "Fri", "Ven"  
  l.store "Sat", "Sam"  
  l.store "Sun", "Dim"
  l.store "Monday", "Lundi"
  l.store "Tuesday", "Mardi"
  l.store "Wednesday", "Mercredi"
  l.store "Thursday", "Jeudi"  
  l.store "Friday", "Vendredi"  
  l.store "Saturday", "Samedi"  
  l.store "Sunday", "Dimanche"
  l.store "Jan", "Jan"    
  l.store "Feb", "Fév"
  l.store "Mar", "Mars"
  l.store "Apr", "Avr"
  l.store "May", "Mai"
  l.store "Jun", "Juin"
  l.store "Jul", "Juil"
  l.store "Aug", "Août"
  l.store "Sep", "Sept"
  l.store "Oct", "Oct"
  l.store "Nov", "Nov"
  l.store "Dec", "Déc"
  l.store "January", "janvier"    
  l.store "February", "février"
  l.store "March", "mars"
  l.store "April", "avril"
  l.store "May", "mai"
  l.store "June", "juin"
  l.store "July", "juillet"
  l.store "August", "août"
  l.store "September", "septembre"
  l.store "October", "octobre"
  l.store "November", "novembre"
  l.store "December", "décembre"
  l.store "%%a, %%d %%b %%Y %%H:%%M:%%S GMT", Proc.new {|date|
     sprintf( date.strftime("%%s %d %%s %Y %H:%M:%S GMT"), _(date.strftime("%a")), _(date.strftime("%b")).downcase )
  }
  l.store "%%d. %%b", Proc.new {|date|
     sprintf( date.strftime("%d. %%s"), _(date.strftime("%b")).downcase )
  }
  l.store "Original article writen by", "Article original écrit par" 
  l.store "and published on", "et publié sur"
  l.store "direct link to this article", "lien direct vers cet article" 
  l.store "If you are reading this article elsewhere than", "Si vous lisez cet article ailleurs que sur" 
  l.store "it has been illegally reproduced and without proper authorization", "c'est qu'il a été reproduit illégalement et sans autorisation"
  l.store "This will display", "Cela affichera"
  l.store "at the bottom of each of your post in the RSS feed", "en bas de chacun de vos articles sur le flux RSS"
  l.store "for", "pour"
  l.store "everything about", "tout sur"
end
